twisted.internet.protocol.Protocol

Package twisted :: Package internet :: Module protocol :: Class Protocol |
[show private | hide private]
[frames | no frames]

## Class Protocol

    BaseProtocol --+
                   |
                  Protocol

Known Subclasses:
  `ProtocolWrapper`

Method Summary
| ``connectionFailed`(self)` (Deprecated)
| ``connectionLost`(self, reason)` Called when the connection is shut down.
| ``dataReceived`(self, data)` Called whenever data is received.

Class Variable Summary
`tuple` | `__implements__` = `(<class 'twisted.internet.interfaces.IP...`

Method Details

### connectionFailed(self) (Deprecated) This used to be called when the connection was not properly established.

### connectionLost(self, reason=<twisted.python.failure.Failure twisted.internet.error.Co...) Called when the connection is shut down. Clear any circular references here, and any external references to this Protocol. The connection has been closed. Parameters: `reason` (type=`twisted.python.failure.Failure`)

### dataReceived(self, data) Called whenever data is received. Use this method to translate to a higher-level message. Usually, some callback will be made upon the receipt of each complete protocol message. Parameters: `data` - a string of indeterminate length. Please keep in mind that you will probably need to buffer some data, as partial (or multiple) protocol messages may be received! I recommend that unit tests for protocols call through to this method with differing chunk sizes, down to one byte at a time.

Class Variable Details

    ### __implements__ Type: `tuple` Value:
        (<class 'twisted.internet.interfaces.IProtocol'>,)

Generated by Epydoc 2.0 on Mon Feb 21 21:56:54 2005 | http://epydoc.sf.net